• Accueil
  • 2026 S06 Rapport Hebdomadaire

Compte rendu du conseil du Mardi soir

blog-thumb

Présents : Jean-Jacques B, Sébastien P, François R.

Excusé :* Laurent C.*

Ordre du jour prochaine visio mardi 10 février 2026 à 21h sur JITSI : https://meet.jit.si/foopgp

Note : Si problème, on ne retrouve sur notre salon NextCloud : https://cloud.foopgp.org/call/yfomgu8q (qui fonctionne à nouveau, quoique toujours un peu sous dimensionné).

  • Points habituels : (revue de presse + déplacements et actions réalisés, en cours, ou à prévoir).

Ordres du soir (mardi 3 février)

  • Retour sur le FOSDEM à Bruxelles (François R)
  • Revue de presse.
  • Point sur les participations et démonstrations publiques.
  • Communication.
  • Actions réalisés, en cours, à prévoir.

Stingynalty

Graphique en 3 dimensions -> https://www.math3d.org/xzuclzIbuZ

Pour février, en appliquant la formule du règlement intérieur , j = log₂(d+1) / stingynalty :

$ bl-foopgp --verbose giftarray --with-header --max 11
bl-foopgp: Info: stingynalty=1.10489557718673078682
|          EUR |          DJI |
|--------------|--------------|
|       1.00 € |   9.05062 dɈ |
|       1.16 € |  10.00000 dɈ |
|       2.00 € |  14.34490 dɈ |
|       3.63 € |  20.00000 dɈ |
|       5.00 € |  23.39553 dɈ |
|       8.95 € |  30.00000 dɈ |
|      10.00 € |  31.31003 dɈ |
|      20.00 € |  39.75323 dɈ |
|      20.41 € |  40.00000 dɈ |
|      45.03 € |  50.00000 dɈ |
|      50.00 € |  51.33901 dɈ |
|      98.01 € |  60.00000 dɈ |
|     100.00 € |  60.26100 dɈ |
|     200.00 € |  69.24683 dɈ |
|     211.94 € |  70.00000 dɈ |
|     456.99 € |  80.00000 dɈ |
|     500.00 € |  81.17207 dɈ |
|     984.06 € |  90.00000 dɈ |
|    1000.00 € |  90.20966 dɈ |
|    2000.00 € |  99.25377 dɈ |
|    2117.69 € | 100.00000 dɈ |
|    4555.95 € | 110.00000 dɈ |

Rappel, si vous avez déjà cotisé, il faut appliquer la formule :

jₙ = log₂( (dₙ+dₜ) + 1 ) / stingynaltyₙ – jₜ

Confer règlement intérieur .

Et pour cela, il faut utiliser les options –tokens et –gifts :

$ bl-foopgp giftarray --help
Usage: bl-foopgp giftarray [OPTIONS]

Afficher un tableau indiquant combien de djis (Ɉ) seront créés à partir d’une cotisation en euros (€).

OPTIONS:
  -t, --tokens DJISUM  Définir la base de djis (Ɉ) déjà créés (par défaut : 0)
  -g, --gifts EURSUM   Définir la base des montants déjà cotisés en euros (€) (par défaut : 0)
  -m, --max VALUE      Définir une limite en nombre de djis ciblés (par défaut : 12)
  -M, --max-line NUM   Limiter le nombre de lignes (par défaut : 24)
  -H, --header-only    Afficher uniquement la ligne d’en-tête, puis quitter.
  -F, --with-header    Afficher également la ligne d’en-tête et une ligne de séparation au début du tableau.

Chiffres de l’association

Au 31 décembre 2025, en utilisant le script ./tools/gifts-stats.sh dans la blockchain qui gère les jetons Ɉ.

  • Total members: 40 - Total certified members: 16 / 40
  • Total contribs: 70 - Total certified contribs: 33 / 70
  • Total contribution: 59503.14 € - Total certified contribution: 50812.51 € / 59503.14 €
  • Total created: 236.044486 Ɉ - Total certified created: 129.063714 Ɉ / 236.044486 Ɉ

Revue de presse

Au cœur de la réunion

$ bl-pgpid certify --help
Utilisation : bl-pgpid certify [OPTIONS]... [TARGET_U4|TARGET_U5] [TARGET_KEYFPR]

Certifier une autre personne, identifiée par son OpenPGP ID TARGET_U4
Les informations manquantes seront demandées de manière interactive. E.g.: Civil status to calculate TARGET_U4.

La certification signifie : je confirme que ce certificat appartient bien à cette personne réelle.
Cela implique de vérifier l’état civil ainsi que l’empreinte de la clé publique de la personne ciblée.
Cela permet d’étendre et de renforcer votre toile de confiance ainsi que celle de vos proches.
This is a commitment: the more you certify, the more you increase your reputation, but if you do it wrong, you will ruin your credibility.

OPTIONS:
  -u, --use-privkey NAME|KEYID Select private key to use. Par défaut : Guess it from connected token, else ask.
  -R, --revoke                 Révoquer vos certifications précédentes sur le certificat d’une autre personne.
  -G, --vouch                  Assumer la responsabilité des actions (éventuellement illégales) de la personne ciblée. Identique à '--vouch-for ALL'. (Not implemented yet)
  -g, --vouch-for DOMAIN       Assumer des responsabilités légales supplémentaires concernant la personne ciblée (Not implemented yet)
  -l, --local                  « Non-exportable » certification. Pretty useless. Allow to less affect credibility.
  -f, --force-sign-key         Allow to unrevoke or to change vouching.
  -k, --keyserver KEYSERVER    Si non vide, recevoir et envoyer le certificat mis à jour vers ce serveur de clés. Par défaut : hkps://keys.foopgp.org.
  -H, --homedir GNUPGHOME      Répertoire personnel de GnuPG (par défaut : ~/.gnupg). Variable d’environnement : $GNUPGHOME.

Actions à mener (TODO list)

  • Urgent: Appel à cotisation.
  • Urgent: Gestion de nos communautés, communication.
  • Urgent: Prospection et gestion commerciales.
  • Génération des relevés de compte à coller ou glisser dans nos carnets d’échanges.

Actions en cours

  • Communication (manque de ressources)
  • Frontend: gestion des emails ou avatars dans nos identités numériques (ajout, suppression)
  • Frontend: gestion de la certification
  • Backend: Fonctionnalités pour consulter ses comptes en djis (Ɉ), faire des paiement en (Ɉ) (grâce à OpenPGP + yubikeys).
  • Backend: generation de svg avec données OpenPGP ID à intégrer dans vos cartes de visite
  • Site web : nouveau site, axé sur Djibian. Moins technique et plus commercial.
  • Collecte d’ordinateurs dotés de Windows obsolètes, pour y installer Djibian (le système qui nous respecte !).
  • Clôture comptable 2025.

(grosses) Actions terminées

  • Backend: gestion de la certification
  • Mise au propre de L’ISO fournit
AMF
  • Nous sommes toujours dans le cadre des “exemptions qui permettent aux émetteurs d’alléger, voire de supprimer le formalisme” de l’article 4, titre II .

Agenda